require "import"
import "android.content.Intent"
import "android.content.pm.PackageManager"
import "android.speech.RecognizerIntent"
import "android.app.Activity"
import "android.widget.Toast"
import "android.speech.tts.TextToSpeech"
import "java.util.Locale"
import "android.widget.*"
import "android.view.*"
import "android.net.Uri"

activity.setTheme(android.R.style.Theme_DeviceDefault_Light_NoActionBar)
activity.setTitle("الأداة الأسطورة")

local VOICE_RECOGNITION_REQUEST_CODE = 100
local tts

-- الواجهة الرئيسية
local mainLayout = {
  LinearLayout,
  orientation = "vertical",
  layout_width = "fill",
  layout_height = "fill",
  gravity = "center",
  padding = "16dp",
  {
    TextView,
    id = "welcomeText",
    text = "مرحبًا بك في الأداة الأسطورة",
    textSize = "20sp",
    textColor = 0xFF000000,
    gravity = "center",
    layout_marginBottom = "24dp"
  },
  {
    Button,
    id = "micButton",
    text = "🎤 اضغط للتحدث",
    layout_width = "wrap",
    layout_height = "wrap",
  },
  {
    Button,
    id = "devButton",
    text = "معلومات المطور",
    layout_width = "wrap",
    layout_height = "wrap",
    layout_marginTop = "24dp"
  }
}

activity.setContentView(loadlayout(mainLayout))

-- شاشة معلومات المطور
function showDeveloperInfo()
  local devLayout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
      LinearLayout,
      orientation = "vertical",
      layout_width = "fill",
      layout_height = "wrap",
      padding = "16dp",
      {
        TextView,
        text = "تطوير الأسطورة",
        textSize = "18sp",
        textColor = 0xFF000000,
        layout_marginBottom = "16dp"
      },
      {
        Button,
        id = "devInfo",
        text = "معلومات المطور",
      },
      {
        Button,
        id = "youtubeButton1",
        text = "قناة المطور على يوتيوب",
      },
      {
        TextView,
        text = "لمزيد من المعلومات والشروحات التقنية، انضموا إلى قناة علي الصقر على يوتيوب.",
        textSize = "16sp",
        textColor = 0xFF444444,
        layout_marginTop = "16dp"
      },
      {
        Button,
        id = "youtubeButton2",
        text = "قناة علي الصقر",
      },
      {
        Button,
        enabled = false,
        text = "للمزيد من التقنيات والألعاب والبرامج انضموا إلى أشهر قناة للمكفوفين.",
      },
      {
        Button,
        id = "youtubeButton3",
        text = "الانضمام إلى أشهر قناة للمكفوفين",
      },
      {
        Button,
        id = "okButton",
        text = "موافق",
        layout_marginTop = "32dp"
      }
    }
  }

  activity.setContentView(loadlayout(devLayout))

  -- أزرار معلومات المطور
  devInfo.onClick = function()
    speakOut("تم تطوير هذه الأداة بواسطة الأسطورة، لدعم المكفوفين وتسهيل استخدام الهاتف بالصوت.")
  end

  youtubeButton1.onClick = function()
    local url = "https://youtube.com/@creativitygatewayfortheblind?si=ngStEeY7g6w1SCIC"
    activity.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse(url)))
  end

  youtubeButton2.onClick = function()
    local url = "https://youtube.com/channel/UCGDLbq1vqQ0SJgFbqP2qCFQ?si=tDX-_GwsDDMe7yUo"
    activity.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse(url)))
  end

  youtubeButton3.onClick = function()
    local url = "https://youtube.com/@ahmedthebest?si=M0-Qk49nhgblsRDn"
    activity.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse(url)))
  end

  okButton.onClick = function()
    activity.recreate() -- يعيدنا للواجهة الرئيسية
  end
end

-- تهيئة TTS
tts = TextToSpeech(activity, TextToSpeech.OnInitListener {
  onInit = function(status)
    if status == TextToSpeech.SUCCESS then
      tts.setLanguage(Locale("ar"))
    else
      showToast("المحول الصوتي غير متاح")
    end
  end
})

-- بدء التعرف الصوتي
function startSpeechRecognition()
  local intent = Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH)
  intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE_MODEL, RecognizerIntent.LANGUAGE_MODEL_FREE_FORM)
  intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE, "ar")
  intent.putExtra(RecognizerIntent.EXTRA_PROMPT, "قل اسم التطبيق")
  activity.startActivityForResult(intent, VOICE_RECOGNITION_REQUEST_CODE)
end

-- نتيجة الصوت
function onActivityResult(requestCode, resultCode, data)
  if requestCode == VOICE_RECOGNITION_REQUEST_CODE then
    if resultCode == Activity.RESULT_OK then
      local matches = data.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS)
      if matches.size() > 0 then
        local appName = matches.get(0)
        openAppByName(appName)
      end
    end
  end
end

-- فتح التطبيق بالاسم
function openAppByName(appName)
  local packageManager = activity.getPackageManager()
  local packageName = getPackageByName(appName, packageManager)
  
  if packageName then
    local intent = packageManager.getLaunchIntentForPackage(packageName)
    if intent then
      intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
      activity.startActivity(intent)
      speakOut("يتم الآن فتح " .. appName)
    end
  else
    speakOut("لم يتم العثور على التطبيق '" .. appName .. "'")
  end
end

-- نطق النص
function speakOut(text)
  if tts then
    tts.speak(text, TextToSpeech.QUEUE_FLUSH, nil, '')
  end
end

-- عرض Toast
function showToast(text)
  Toast.makeText(activity, text, Toast.LENGTH_SHORT).show()
end

-- البحث عن اسم الحزمة
function getPackageByName(appName, packageManager)
  local packages = packageManager.getInstalledApplications(PackageManager.GET_META_DATA)
  for i = 0, packages.size() - 1 do
    local packageInfo = packages.get(i)
    local label = tostring(packageManager.getApplicationLabel(packageInfo))
    if label:lower():find(appName:lower()) then
      return packageInfo.packageName
    end
  end
  return nil
end

-- تنظيف TTS
function onDestroy()
  if tts then
    tts.stop()
    tts.shutdown()
    tts = nil
  end
end

-- أحداث الأزرار في الواجهة الرئيسية
micButton.onClick = function()
  startSpeechRecognition()
end

devButton.onClick = function()
  showDeveloperInfo()
end